# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RelatedReportResponse(Model):
    """RelatedReportResponse.

    :param specific_report_id: Specific report id of the related report
    :type specific_report_id: int
    :param name: Name of the related report
    :type name: str
    :param description: Description of the related report
    :type description: str
    :param report_source: The rendering engine used for the report (EnergyCAP
     currently uses SSRS and Crystal)
    :type report_source: str
    """

    _attribute_map = {
        'specific_report_id': {'key': 'specificReportId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'report_source': {'key': 'reportSource', 'type': 'str'},
    }

    def __init__(self, *, specific_report_id: int=None, name: str=None, description: str=None, report_source: str=None, **kwargs) -> None:
        super(RelatedReportResponse, self).__init__(**kwargs)
        self.specific_report_id = specific_report_id
        self.name = name
        self.description = description
        self.report_source = report_source



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecialAdjustmentMethod(Model):
    """SpecialAdjustmentMethod.

    :param label: Description of Special Adjustment method
    :type label: str
    :param special_adjustment_method_id: Special Adjustment Method ID
    :type special_adjustment_method_id: int
    :param electric_only: Indicates whether or not this method is for Electric
     meters only
    :type electric_only: bool
    :param symbol: The symbol for the Special Adjustment's input value
    :type symbol: str
    :param precision: The precision on the Special Adjustment's input value
    :type precision: int
    """

    _attribute_map = {
        'label': {'key': 'label', 'type': 'str'},
        'special_adjustment_method_id': {'key': 'specialAdjustmentMethodId', 'type': 'int'},
        'electric_only': {'key': 'electricOnly', 'type': 'bool'},
        'symbol': {'key': 'symbol', 'type': 'str'},
        'precision': {'key': 'precision', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(SpecialAdjustmentMethod, self).__init__(**kwargs)
        self.label = kwargs.get('label', None)
        self.special_adjustment_method_id = kwargs.get('special_adjustment_method_id', None)
        self.electric_only = kwargs.get('electric_only', None)
        self.symbol = kwargs.get('symbol', None)
        self.precision = kwargs.get('precision', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Environment(Model):
    """Environment.

    :param build_date:
    :type build_date: datetime
    :param version:
    :type version: str
    """

    _attribute_map = {
        'build_date': {'key': 'buildDate', 'type': 'iso-8601'},
        'version': {'key': 'version', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(Environment, self).__init__(**kwargs)
        self.build_date = kwargs.get('build_date', None)
        self.version = kwargs.get('version', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountUDFResponse(Model):
    """AccountUDFResponse.

    :param account_id: The account identifier
    :type account_id: int
    :param account_code: The account code
    :type account_code: str
    :param account_info: The account info
    :type account_info: str
    :param udfs: An array of user-defined fields (UDFs)
    :type udfs: list[~energycap.sdk.models.UDFFieldChild]
    """

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'udfs': {'key': 'udfs', 'type': '[UDFFieldChild]'},
    }

    def __init__(self, **kwargs):
        super(AccountUDFResponse, self).__init__(**kwargs)
        self.account_id = kwargs.get('account_id', None)
        self.account_code = kwargs.get('account_code', None)
        self.account_info = kwargs.get('account_info', None)
        self.udfs = kwargs.get('udfs', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceGroupDigestAreaRankingResponse(Model):
    """PlaceGroupDigestAreaRankingResponse.

    :param high_cost: Highest cost for this group
    :type high_cost: float
    :param low_cost: Lowest cost for this group
    :type low_cost: float
    :param average_cost: Average cost for this group
    :type average_cost: float
    :param median_cost: Median cost for this group
    :type median_cost: float
    :param high_use: Highest use for this group
    :type high_use: float
    :param low_use: Lowest use for this group
    :type low_use: float
    :param average_use: Average use for this group
    :type average_use: float
    :param median_use: Median use for this group
    :type median_use: float
    :param high_value: Highest benchmark value for this group
    :type high_value: float
    :param low_value: Lowest benchmark value for this group
    :type low_value: float
    :param median_value: Median benchmark value for this group
    :type median_value: float
    :param total_area: Total area for this group
    :type total_area: float
    :param high_area: Highest area for this group
    :type high_area: float
    :param low_area: Lowest area for this group
    :type low_area: float
    :param median_area: Median area for this group
    :type median_area: float
    :param high_savings_opportunity: The highest savings opportunity for this
     group
    :type high_savings_opportunity: float
    :param results:
    :type results:
     list[~energycap.sdk.models.PlaceGroupDigestAreaRankingChild]
    :param place_group_id:
    :type place_group_id: int
    :param place_group_code:
    :type place_group_code: str
    :param place_group_info:
    :type place_group_info: str
    :param place_group_display: This is the user's preferred way of viewing
     this entity - could be code or info based on the master "data object view"
     setting in DB
    :type place_group_display: str
    :param benchmark_unit: This will provide the benchmark unit eg:MMBTU/ft²
     or $/day
    :type benchmark_unit: str
    :param benchmark_factor_unit: This will provide the unit for the
     benchmarking factor eg:ft² or day
    :type benchmark_factor_unit: str
    :param benchmark_value_unit: This will provide the unit for the benchmark
     value eg:$ for cost/day, MMBTU for annualized use/area
    :type benchmark_value_unit: str
    :param use_unit:
    :type use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param updated: The date and time the data was updated
    :type updated: datetime
    """

    _attribute_map = {
        'high_cost': {'key': 'highCost', 'type': 'float'},
        'low_cost': {'key': 'lowCost', 'type': 'float'},
        'average_cost': {'key': 'averageCost', 'type': 'float'},
        'median_cost': {'key': 'medianCost', 'type': 'float'},
        'high_use': {'key': 'highUse', 'type': 'float'},
        'low_use': {'key': 'lowUse', 'type': 'float'},
        'average_use': {'key': 'averageUse', 'type': 'float'},
        'median_use': {'key': 'medianUse', 'type': 'float'},
        'high_value': {'key': 'highValue', 'type': 'float'},
        'low_value': {'key': 'lowValue', 'type': 'float'},
        'median_value': {'key': 'medianValue', 'type': 'float'},
        'total_area': {'key': 'totalArea', 'type': 'float'},
        'high_area': {'key': 'highArea', 'type': 'float'},
        'low_area': {'key': 'lowArea', 'type': 'float'},
        'median_area': {'key': 'medianArea', 'type': 'float'},
        'high_savings_opportunity': {'key': 'highSavingsOpportunity', 'type': 'float'},
        'results': {'key': 'results', 'type': '[PlaceGroupDigestAreaRankingChild]'},
        'place_group_id': {'key': 'placeGroupId', 'type': 'int'},
        'place_group_code': {'key': 'placeGroupCode', 'type': 'str'},
        'place_group_info': {'key': 'placeGroupInfo', 'type': 'str'},
        'place_group_display': {'key': 'placeGroupDisplay', 'type': 'str'},
        'benchmark_unit': {'key': 'benchmarkUnit', 'type': 'str'},
        'benchmark_factor_unit': {'key': 'benchmarkFactorUnit', 'type': 'str'},
        'benchmark_value_unit': {'key': 'benchmarkValueUnit', 'type': 'str'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(PlaceGroupDigestAreaRankingResponse, self).__init__(**kwargs)
        self.high_cost = kwargs.get('high_cost', None)
        self.low_cost = kwargs.get('low_cost', None)
        self.average_cost = kwargs.get('average_cost', None)
        self.median_cost = kwargs.get('median_cost', None)
        self.high_use = kwargs.get('high_use', None)
        self.low_use = kwargs.get('low_use', None)
        self.average_use = kwargs.get('average_use', None)
        self.median_use = kwargs.get('median_use', None)
        self.high_value = kwargs.get('high_value', None)
        self.low_value = kwargs.get('low_value', None)
        self.median_value = kwargs.get('median_value', None)
        self.total_area = kwargs.get('total_area', None)
        self.high_area = kwargs.get('high_area', None)
        self.low_area = kwargs.get('low_area', None)
        self.median_area = kwargs.get('median_area', None)
        self.high_savings_opportunity = kwargs.get('high_savings_opportunity', None)
        self.results = kwargs.get('results', None)
        self.place_group_id = kwargs.get('place_group_id', None)
        self.place_group_code = kwargs.get('place_group_code', None)
        self.place_group_info = kwargs.get('place_group_info', None)
        self.place_group_display = kwargs.get('place_group_display', None)
        self.benchmark_unit = kwargs.get('benchmark_unit', None)
        self.benchmark_factor_unit = kwargs.get('benchmark_factor_unit', None)
        self.benchmark_value_unit = kwargs.get('benchmark_value_unit', None)
        self.use_unit = kwargs.get('use_unit', None)
        self.cost_unit = kwargs.get('cost_unit', None)
        self.updated = kwargs.get('updated', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarTaskPlaceChild(Model):
    """EnergyStarTaskPlaceChild.

    :param building:
    :type building: ~energycap.sdk.models.PlaceChild
    :param task_periods: The list of submission or metrics periods for the
     task
    :type task_periods: list[~energycap.sdk.models.NamedPeriod]
    """

    _attribute_map = {
        'building': {'key': 'building', 'type': 'PlaceChild'},
        'task_periods': {'key': 'taskPeriods', 'type': '[NamedPeriod]'},
    }

    def __init__(self, *, building=None, task_periods=None, **kwargs) -> None:
        super(EnergyStarTaskPlaceChild, self).__init__(**kwargs)
        self.building = building
        self.task_periods = task_periods



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SavingsDailyData(Model):
    """SavingsDaily Data - a class that represents CA Savings for a given day per
    meter/bill.

    :param batcc_non_weather_native_use: Baseline Adjusted to Current
     Conditions (BATCC) non-weather use in native units
    :type batcc_non_weather_native_use: float
    :param batcc_weather_native_use: Baseline Adjusted to Current Conditions
     (BATCC) weather use in native units
    :type batcc_weather_native_use: float
    :param baseline_non_weather_native_use: Baseline non-weather Use in native
     units
    :type baseline_non_weather_native_use: float
    :param baseline_weather_native_use: Baseline weather use in native units
    :type baseline_weather_native_use: float
    :param batcc_cost: Baseline Adjusted to Current Conditions (BATCC) cost
    :type batcc_cost: float
    :param average_unit_cost: Average unit cost
    :type average_unit_cost: float
    :param baseline_cooling_degree_days: Number of cooling degrees used on
     this day in the baseline
    :type baseline_cooling_degree_days: int
    :param current_cooling_degree_days: Number of cooling degrees used on this
     day
    :type current_cooling_degree_days: int
    :param baseline_heating_degree_days: Number of heating degrees used on
     this day in the baseline
    :type baseline_heating_degree_days: int
    :param current_heating_degree_days: Number of heating degrees used on this
     day
    :type current_heating_degree_days: int
    :param special_adjustment: Indicates whether or not a Special Adjustment
     was in effect on this day
    :type special_adjustment: bool
    :param area_adjustment: Indicates whether or not an Area Adjustment was in
     effect on this day
    :type area_adjustment: bool
    :param weather_adjustment: Indicates whether or not Weather Adjustment was
     in effect on this day
    :type weather_adjustment: bool
    :param other_adjustment: Indicates whether or not Other Adjustment was in
     effect on this day
    :type other_adjustment: bool
    :param date_property: Daily savings date
    :type date_property: datetime
    :param messages: List of Processor Messages for this day
    :type messages: list[~energycap.sdk.models.Message]
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'batcc_non_weather_native_use': {'key': 'batccNonWeatherNativeUse', 'type': 'float'},
        'batcc_weather_native_use': {'key': 'batccWeatherNativeUse', 'type': 'float'},
        'baseline_non_weather_native_use': {'key': 'baselineNonWeatherNativeUse', 'type': 'float'},
        'baseline_weather_native_use': {'key': 'baselineWeatherNativeUse', 'type': 'float'},
        'batcc_cost': {'key': 'batccCost', 'type': 'float'},
        'average_unit_cost': {'key': 'averageUnitCost', 'type': 'float'},
        'baseline_cooling_degree_days': {'key': 'baselineCoolingDegreeDays', 'type': 'int'},
        'current_cooling_degree_days': {'key': 'currentCoolingDegreeDays', 'type': 'int'},
        'baseline_heating_degree_days': {'key': 'baselineHeatingDegreeDays', 'type': 'int'},
        'current_heating_degree_days': {'key': 'currentHeatingDegreeDays', 'type': 'int'},
        'special_adjustment': {'key': 'specialAdjustment', 'type': 'bool'},
        'area_adjustment': {'key': 'areaAdjustment', 'type': 'bool'},
        'weather_adjustment': {'key': 'weatherAdjustment', 'type': 'bool'},
        'other_adjustment': {'key': 'otherAdjustment', 'type': 'bool'},
        'date_property': {'key': 'date', 'type': 'iso-8601'},
        'messages': {'key': 'messages', 'type': '[Message]'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
    }

    def __init__(self, **kwargs):
        super(SavingsDailyData, self).__init__(**kwargs)
        self.batcc_non_weather_native_use = kwargs.get('batcc_non_weather_native_use', None)
        self.batcc_weather_native_use = kwargs.get('batcc_weather_native_use', None)
        self.baseline_non_weather_native_use = kwargs.get('baseline_non_weather_native_use', None)
        self.baseline_weather_native_use = kwargs.get('baseline_weather_native_use', None)
        self.batcc_cost = kwargs.get('batcc_cost', None)
        self.average_unit_cost = kwargs.get('average_unit_cost', None)
        self.baseline_cooling_degree_days = kwargs.get('baseline_cooling_degree_days', None)
        self.current_cooling_degree_days = kwargs.get('current_cooling_degree_days', None)
        self.baseline_heating_degree_days = kwargs.get('baseline_heating_degree_days', None)
        self.current_heating_degree_days = kwargs.get('current_heating_degree_days', None)
        self.special_adjustment = kwargs.get('special_adjustment', None)
        self.area_adjustment = kwargs.get('area_adjustment', None)
        self.weather_adjustment = kwargs.get('weather_adjustment', None)
        self.other_adjustment = kwargs.get('other_adjustment', None)
        self.date_property = kwargs.get('date_property', None)
        self.messages = kwargs.get('messages', None)
        self.cost_unit = kwargs.get('cost_unit', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillAccrualExclusionRequest(Model):
    """BillAccrualExclusionRequest.

    All required parameters must be populated in order to send to Azure.

    :param bill_ids: Required. List of bill IDs to exclude from accruals or
     include again <span class='property-internal'>Required</span>
    :type bill_ids: list[int]
    :param exclude: Required. Whether or not the bill ids should be excluded
     from accruals, or included again <span
     class='property-internal'>Required</span>
    :type exclude: bool
    """

    _validation = {
        'bill_ids': {'required': True},
        'exclude': {'required': True},
    }

    _attribute_map = {
        'bill_ids': {'key': 'billIds', 'type': '[int]'},
        'exclude': {'key': 'exclude', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(BillAccrualExclusionRequest, self).__init__(**kwargs)
        self.bill_ids = kwargs.get('bill_ids', None)
        self.exclude = kwargs.get('exclude', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFEdit(Model):
    """UDFEdit.

    All required parameters must be populated in order to send to Azure.

    :param name: Required. The UDF's name <span
     class='property-internal'>Required</span>
    :type name: str
    :param display_order: Required. <p>The UDF's display order</p>
     <p>A value of 1 or less will put this record the beginning of the list</p>
     <p>A value greater than the stored max will put this record at the end of
     the list</p>
     <p>When the old display order of the UDF being updated is less than the
     new specified display order, decrement the display order of all other UDFs
     falling between the old and new display order</p>
     <p>When the old display order of the UDF being updated is greater than the
     new specified display order, increment the display order of all other UDFs
     falling between the old and new display order</p>
     <p>All UDF lying outside the range of display orders being updated retain
     their original values</p> <span class='property-internal'>Required</span>
    :type display_order: int
    :param udf_select_values: <p>An array of options to populate a UDF select
     list.</p>
     <p>Required when the UDF being edited has a dataTypeId of 12 otherwise
     this will be ignored.</p>
     <p>To remove an option from the select list, omit it from this array.
     Options that are in use may not be deleted. To add a new option, pass in
     null as the udfSelectValueId</p>
    :type udf_select_values: list[~energycap.sdk.models.UDFSelectValueEdit]
    """

    _validation = {
        'name': {'required': True},
        'display_order': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'udf_select_values': {'key': 'udfSelectValues', 'type': '[UDFSelectValueEdit]'},
    }

    def __init__(self, **kwargs):
        super(UDFEdit, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.display_order = kwargs.get('display_order', None)
        self.udf_select_values = kwargs.get('udf_select_values', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarCommodityMeterTypeMappingChild(Model):
    """EnergyStarCommodityMeterTypeMappingChild.

    :param pm_unit_code: The unit code in Portfolio Manager
    :type pm_unit_code: str
    :param is_delivery: When true, auto-created Portfolio Manager meters of
     this commodity are serviced "by delivery" rather than "by metering"
    :type is_delivery: bool
    :param suported_pm_commodities_with_default: List of supported Portfolio
     Manager commodities for this ECAP Commodity
     Every entry includes the commodity code and whether the commodity is the
     default for Portfolio Manager
    :type suported_pm_commodities_with_default:
     list[~energycap.sdk.models.PmCommodityChild]
    """

    _attribute_map = {
        'pm_unit_code': {'key': 'pmUnitCode', 'type': 'str'},
        'is_delivery': {'key': 'isDelivery', 'type': 'bool'},
        'suported_pm_commodities_with_default': {'key': 'suportedPmCommoditiesWithDefault', 'type': '[PmCommodityChild]'},
    }

    def __init__(self, *, pm_unit_code: str=None, is_delivery: bool=None, suported_pm_commodities_with_default=None, **kwargs) -> None:
        super(EnergyStarCommodityMeterTypeMappingChild, self).__init__(**kwargs)
        self.pm_unit_code = pm_unit_code
        self.is_delivery = is_delivery
        self.suported_pm_commodities_with_default = suported_pm_commodities_with_default



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestEnergyUseIntensityEuiEnergyProject(Model):
    """PlaceDigestEnergyUseIntensityEuiEnergyProject.

    :param energy_project_id: The energy project identifier
    :type energy_project_id: int
    :param energy_project_code: The energy project code
    :type energy_project_code: str
    :param energy_project_info: The energy project info
    :type energy_project_info: str
    :param installation_cost: The energy project installation cost
    :type installation_cost: float
    """

    _attribute_map = {
        'energy_project_id': {'key': 'energyProjectId', 'type': 'int'},
        'energy_project_code': {'key': 'energyProjectCode', 'type': 'str'},
        'energy_project_info': {'key': 'energyProjectInfo', 'type': 'str'},
        'installation_cost': {'key': 'installationCost', 'type': 'float'},
    }

    def __init__(self, *, energy_project_id: int=None, energy_project_code: str=None, energy_project_info: str=None, installation_cost: float=None, **kwargs) -> None:
        super(PlaceDigestEnergyUseIntensityEuiEnergyProject, self).__init__(**kwargs)
        self.energy_project_id = energy_project_id
        self.energy_project_code = energy_project_code
        self.energy_project_info = energy_project_info
        self.installation_cost = installation_cost



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountOrMeterUsage(Model):
    """AccountOrMeterUsage.

    :param chargeback: Number of chargeback accounts or meters.
    :type chargeback: int
    :param non_chargeback: Number of non-chargeback accounts or meters.
    :type non_chargeback: int
    :param inactive: Number of inactive accounts or meters.
    :type inactive: int
    """

    _attribute_map = {
        'chargeback': {'key': 'chargeback', 'type': 'int'},
        'non_chargeback': {'key': 'nonChargeback', 'type': 'int'},
        'inactive': {'key': 'inactive', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(AccountOrMeterUsage, self).__init__(**kwargs)
        self.chargeback = kwargs.get('chargeback', None)
        self.non_chargeback = kwargs.get('non_chargeback', None)
        self.inactive = kwargs.get('inactive', None)
